
TODO: TODO_06_54_83_58: extend via func instead of delegator

The primary concept for extension should be function - defined as `func_id` with `search_control`.

So far, delegator plugin only served as a common module to define related functions.

In the long run, instead of writing delegators, users should write individual functions.
